---
name: Refactoring
about: Refactor
title: <Insert Title>
labels: refactoring
assignees: ''

---

# Summary
<!---
A short description of the planed refactoring (TL;DR)
--->

# Details
<!---
A detailed description about what and how it should be refactored, background, links, context information
and example(s) of how "the refactoring should look".
--->

## Background & Context
<!---
What is the motivation for the refactoring?
Assessment of the refactoring. Pros & cons, solutions and decisions concerning (reasoning) the refactoring.
--->

## Examples
<!---
Examples of how "the refactoring should look".
--->

## References
<!---
Further references to e.g. other information resources like links to specification(s) etc.
--->

# Task(s)
<!---
A task list containing common tasks associated with this kind of issue, but also tasks specific to this issue.

e.g.:
- [ ] Implement/Refactor XYZ
- [ ] Add tests for XYZ
- [ ] Bump version number
- [ ] Update changelog
- [ ] ...
--->
